@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.113-3-g01935c2
+package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.114-9-g197f8a5
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 # ABSTRACT: A plugin bundle for distributions built by ETHER
 # KEYWORDS: author bundle distribution tool
 
-our $VERSION = '0.114';
+our $VERSION = '0.115';
 
 use Moose;
 with
@@ -233,9 +233,9 @@ sub configure
         [ 'Test::MinimumVersion' => { ':version' => '2.000003', max_target_perl => '5.006' } ],
         [ 'PodSyntaxTests'      => { ':version' => '5.040' } ],
         [ 'PodCoverageTests'    => { ':version' => '5.040' } ],
-        [ 'Test::PodSpelling'   => { ':version' => '2.006003', stopwords => ['irc'] } ],
+        [ 'Test::PodSpelling'   => { ':version' => '2.006003', stopwords => ['irc'], directories => [qw(examples lib script t xt)] } ],
         #[Test::Pod::LinkCheck]     many outstanding bugs
-        [ 'Test::Pod::No404s'   => { ':version' => '1.002' } ],
+        [ 'Test::Pod::No404s'   => { ':version' => '1.003' } ],
         [ 'Test::Kwalitee'      => { ':version' => '2.10', filename => 'xt/author/kwalitee.t' } ],
         [ 'MojibakeTests'       => { ':version' => '0.8' } ],
         [ 'Test::ReportPrereqs' => { ':version' => '0.022', verify_prereqs => 1, version_extractor => 'Module::Metadata',
@@ -277,7 +277,7 @@ sub configure
         # Register Prereqs
         # (MakeMaker or other installer)
         [ 'AutoPrereqs'         => { ':version' => '5.038' } ],
-        'Prereqs::AuthorDeps',
+        [ 'Prereqs::AuthorDeps' => { ':version' => '0.006' } ],
         [ 'MinimumPerl'         => { ':version' => '1.006', configure_finder => ':NoFiles' } ],
         [ 'Prereqs' => pluginbundle_version => {
                 '-phase' => 'develop', '-relationship' => 'recommends',
@@ -457,7 +457,7 @@ Dist::Zilla::PluginBundle::Author::ETHER - A plugin bundle for distributions bui
 
 =head1 VERSION
 
-version 0.114
+version 0.115
 
 =head1 SYNOPSIS
 
@@ -569,10 +569,15 @@ following F<dist.ini> (following the preamble), minus some optimizations:
     [Test::PodSpelling]
     :version = 2.006003
     stopwords = irc
+    directory = examples
+    directory = lib
+    directory = script
+    directory = t
+    directory = xt
 
     ;[Test::Pod::LinkCheck]     many outstanding bugs
     [Test::Pod::No404s]
-    :version = 1.002
+    :version = 1.003
     [Test::Kwalitee]
     :version = 2.10
     filename = xt/author/kwalitee.t
